# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/staking/v1beta1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from cosmos.staking.v1beta1 import staking_pb2 as cosmos_dot_staking_dot_v1beta1_dot_staking__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"cosmos/staking/v1beta1/query.proto\x12\x16\x63osmos.staking.v1beta1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a$cosmos/staking/v1beta1/staking.proto\"d\n\x16QueryValidatorsRequest\x12\x0e\n\x06status\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x93\x01\n\x17QueryValidatorsResponse\x12;\n\nvalidators\x18\x01 \x03(\x0b\x32!.cosmos.staking.v1beta1.ValidatorB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"/\n\x15QueryValidatorRequest\x12\x16\n\x0evalidator_addr\x18\x01 \x01(\t\"T\n\x16QueryValidatorResponse\x12:\n\tvalidator\x18\x01 \x01(\x0b\x32!.cosmos.staking.v1beta1.ValidatorB\x04\xc8\xde\x1f\x00\"v\n QueryValidatorDelegationsRequest\x12\x16\n\x0evalidator_addr\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\xc7\x01\n!QueryValidatorDelegationsResponse\x12\x65\n\x14\x64\x65legation_responses\x18\x01 \x03(\x0b\x32*.cosmos.staking.v1beta1.DelegationResponseB\x1b\xc8\xde\x1f\x00\xaa\xdf\x1f\x13\x44\x65legationResponses\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\x7f\n)QueryValidatorUnbondingDelegationsRequest\x12\x16\n\x0evalidator_addr\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\xb9\x01\n*QueryValidatorUnbondingDelegationsResponse\x12N\n\x13unbonding_responses\x18\x01 \x03(\x0b\x32+.cosmos.staking.v1beta1.UnbondingDelegationB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"R\n\x16QueryDelegationRequest\x12\x16\n\x0e\x64\x65legator_addr\x18\x01 \x01(\t\x12\x16\n\x0evalidator_addr\x18\x02 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"b\n\x17QueryDelegationResponse\x12G\n\x13\x64\x65legation_response\x18\x01 \x01(\x0b\x32*.cosmos.staking.v1beta1.DelegationResponse\"[\n\x1fQueryUnbondingDelegationRequest\x12\x16\n\x0e\x64\x65legator_addr\x18\x01 \x01(\t\x12\x16\n\x0evalidator_addr\x18\x02 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"e\n QueryUnbondingDelegationResponse\x12\x41\n\x06unbond\x18\x01 \x01(\x0b\x32+.cosmos.staking.v1beta1.UnbondingDelegationB\x04\xc8\xde\x1f\x00\"\x80\x01\n QueryDelegatorDelegationsRequest\x12\x16\n\x0e\x64\x65legator_addr\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\xb0\x01\n!QueryDelegatorDelegationsResponse\x12N\n\x14\x64\x65legation_responses\x18\x01 \x03(\x0b\x32*.cosmos.staking.v1beta1.DelegationResponseB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\x89\x01\n)QueryDelegatorUnbondingDelegationsRequest\x12\x16\n\x0e\x64\x65legator_addr\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\xb9\x01\n*QueryDelegatorUnbondingDelegationsResponse\x12N\n\x13unbonding_responses\x18\x01 \x03(\x0b\x32+.cosmos.staking.v1beta1.UnbondingDelegationB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\xb1\x01\n\x19QueryRedelegationsRequest\x12\x16\n\x0e\x64\x65legator_addr\x18\x01 \x01(\t\x12\x1a\n\x12src_validator_addr\x18\x02 \x01(\t\x12\x1a\n\x12\x64st_validator_addr\x18\x03 \x01(\t\x12:\n\npagination\x18\x04 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\xad\x01\n\x1aQueryRedelegationsResponse\x12R\n\x16redelegation_responses\x18\x01 \x03(\x0b\x32,.cosmos.staking.v1beta1.RedelegationResponseB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\x7f\n\x1fQueryDelegatorValidatorsRequest\x12\x16\n\x0e\x64\x65legator_addr\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x9c\x01\n QueryDelegatorValidatorsResponse\x12;\n\nvalidators\x18\x01 \x03(\x0b\x32!.cosmos.staking.v1beta1.ValidatorB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"Z\n\x1eQueryDelegatorValidatorRequest\x12\x16\n\x0e\x64\x65legator_addr\x18\x01 \x01(\t\x12\x16\n\x0evalidator_addr\x18\x02 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"]\n\x1fQueryDelegatorValidatorResponse\x12:\n\tvalidator\x18\x01 \x01(\x0b\x32!.cosmos.staking.v1beta1.ValidatorB\x04\xc8\xde\x1f\x00\",\n\x1aQueryHistoricalInfoRequest\x12\x0e\n\x06height\x18\x01 \x01(\x03\"S\n\x1bQueryHistoricalInfoResponse\x12\x34\n\x04hist\x18\x01 \x01(\x0b\x32&.cosmos.staking.v1beta1.HistoricalInfo\"\x12\n\x10QueryPoolRequest\"E\n\x11QueryPoolResponse\x12\x30\n\x04pool\x18\x01 \x01(\x0b\x32\x1c.cosmos.staking.v1beta1.PoolB\x04\xc8\xde\x1f\x00\"\x14\n\x12QueryParamsRequest\"K\n\x13QueryParamsResponse\x12\x34\n\x06params\x18\x01 \x01(\x0b\x32\x1e.cosmos.staking.v1beta1.ParamsB\x04\xc8\xde\x1f\x00\x32\xea\x15\n\x05Query\x12\x99\x01\n\nValidators\x12..cosmos.staking.v1beta1.QueryValidatorsRequest\x1a/.cosmos.staking.v1beta1.QueryValidatorsResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/cosmos/staking/v1beta1/validators\x12\xa7\x01\n\tValidator\x12-.cosmos.staking.v1beta1.QueryValidatorRequest\x1a..cosmos.staking.v1beta1.QueryValidatorResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/cosmos/staking/v1beta1/validators/{validator_addr}\x12\xd4\x01\n\x14ValidatorDelegations\x12\x38.cosmos.staking.v1beta1.QueryValidatorDelegationsRequest\x1a\x39.cosmos.staking.v1beta1.QueryValidatorDelegationsResponse\"G\x82\xd3\xe4\x93\x02\x41\x12?/cosmos/staking/v1beta1/validators/{validator_addr}/delegations\x12\xf9\x01\n\x1dValidatorUnbondingDelegations\x12\x41.cosmos.staking.v1beta1.QueryValidatorUnbondingDelegationsRequest\x1a\x42.cosmos.staking.v1beta1.QueryValidatorUnbondingDelegationsResponse\"Q\x82\xd3\xe4\x93\x02K\x12I/cosmos/staking/v1beta1/validators/{validator_addr}/unbonding_delegations\x12\xc7\x01\n\nDelegation\x12..cosmos.staking.v1beta1.QueryDelegationRequest\x1a/.cosmos.staking.v1beta1.QueryDelegationResponse\"X\x82\xd3\xe4\x93\x02R\x12P/cosmos/staking/v1beta1/validators/{validator_addr}/delegations/{delegator_addr}\x12\xf7\x01\n\x13UnbondingDelegation\x12\x37.cosmos.staking.v1beta1.QueryUnbondingDelegationRequest\x1a\x38.cosmos.staking.v1beta1.QueryUnbondingDelegationResponse\"m\x82\xd3\xe4\x93\x02g\x12\x65/cosmos/staking/v1beta1/validators/{validator_addr}/delegations/{delegator_addr}/unbonding_delegation\x12\xc9\x01\n\x14\x44\x65legatorDelegations\x12\x38.cosmos.staking.v1beta1.QueryDelegatorDelegationsRequest\x1a\x39.cosmos.staking.v1beta1.QueryDelegatorDelegationsResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/cosmos/staking/v1beta1/delegations/{delegator_addr}\x12\xf9\x01\n\x1d\x44\x65legatorUnbondingDelegations\x12\x41.cosmos.staking.v1beta1.QueryDelegatorUnbondingDelegationsRequest\x1a\x42.cosmos.staking.v1beta1.QueryDelegatorUnbondingDelegationsResponse\"Q\x82\xd3\xe4\x93\x02K\x12I/cosmos/staking/v1beta1/delegators/{delegator_addr}/unbonding_delegations\x12\xc1\x01\n\rRedelegations\x12\x31.cosmos.staking.v1beta1.QueryRedelegationsRequest\x1a\x32.cosmos.staking.v1beta1.QueryRedelegationsResponse\"I\x82\xd3\xe4\x93\x02\x43\x12\x41/cosmos/staking/v1beta1/delegators/{delegator_addr}/redelegations\x12\xd0\x01\n\x13\x44\x65legatorValidators\x12\x37.cosmos.staking.v1beta1.QueryDelegatorValidatorsRequest\x1a\x38.cosmos.staking.v1beta1.QueryDelegatorValidatorsResponse\"F\x82\xd3\xe4\x93\x02@\x12>/cosmos/staking/v1beta1/delegators/{delegator_addr}/validators\x12\xde\x01\n\x12\x44\x65legatorValidator\x12\x36.cosmos.staking.v1beta1.QueryDelegatorValidatorRequest\x1a\x37.cosmos.staking.v1beta1.QueryDelegatorValidatorResponse\"W\x82\xd3\xe4\x93\x02Q\x12O/cosmos/staking/v1beta1/delegators/{delegator_addr}/validators/{validator_addr}\x12\xb3\x01\n\x0eHistoricalInfo\x12\x32.cosmos.staking.v1beta1.QueryHistoricalInfoRequest\x1a\x33.cosmos.staking.v1beta1.QueryHistoricalInfoResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/cosmos/staking/v1beta1/historical_info/{height}\x12\x81\x01\n\x04Pool\x12(.cosmos.staking.v1beta1.QueryPoolRequest\x1a).cosmos.staking.v1beta1.QueryPoolResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/cosmos/staking/v1beta1/pool\x12\x89\x01\n\x06Params\x12*.cosmos.staking.v1beta1.QueryParamsRequest\x1a+.cosmos.staking.v1beta1.QueryParamsResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/cosmos/staking/v1beta1/paramsB.Z,github.com/cosmos/cosmos-sdk/x/staking/typesb\x06proto3')



_QUERYVALIDATORSREQUEST = DESCRIPTOR.message_types_by_name['QueryValidatorsRequest']
_QUERYVALIDATORSRESPONSE = DESCRIPTOR.message_types_by_name['QueryValidatorsResponse']
_QUERYVALIDATORREQUEST = DESCRIPTOR.message_types_by_name['QueryValidatorRequest']
_QUERYVALIDATORRESPONSE = DESCRIPTOR.message_types_by_name['QueryValidatorResponse']
_QUERYVALIDATORDELEGATIONSREQUEST = DESCRIPTOR.message_types_by_name['QueryValidatorDelegationsRequest']
_QUERYVALIDATORDELEGATIONSRESPONSE = DESCRIPTOR.message_types_by_name['QueryValidatorDelegationsResponse']
_QUERYVALIDATORUNBONDINGDELEGATIONSREQUEST = DESCRIPTOR.message_types_by_name['QueryValidatorUnbondingDelegationsRequest']
_QUERYVALIDATORUNBONDINGDELEGATIONSRESPONSE = DESCRIPTOR.message_types_by_name['QueryValidatorUnbondingDelegationsResponse']
_QUERYDELEGATIONREQUEST = DESCRIPTOR.message_types_by_name['QueryDelegationRequest']
_QUERYDELEGATIONRESPONSE = DESCRIPTOR.message_types_by_name['QueryDelegationResponse']
_QUERYUNBONDINGDELEGATIONREQUEST = DESCRIPTOR.message_types_by_name['QueryUnbondingDelegationRequest']
_QUERYUNBONDINGDELEGATIONRESPONSE = DESCRIPTOR.message_types_by_name['QueryUnbondingDelegationResponse']
_QUERYDELEGATORDELEGATIONSREQUEST = DESCRIPTOR.message_types_by_name['QueryDelegatorDelegationsRequest']
_QUERYDELEGATORDELEGATIONSRESPONSE = DESCRIPTOR.message_types_by_name['QueryDelegatorDelegationsResponse']
_QUERYDELEGATORUNBONDINGDELEGATIONSREQUEST = DESCRIPTOR.message_types_by_name['QueryDelegatorUnbondingDelegationsRequest']
_QUERYDELEGATORUNBONDINGDELEGATIONSRESPONSE = DESCRIPTOR.message_types_by_name['QueryDelegatorUnbondingDelegationsResponse']
_QUERYREDELEGATIONSREQUEST = DESCRIPTOR.message_types_by_name['QueryRedelegationsRequest']
_QUERYREDELEGATIONSRESPONSE = DESCRIPTOR.message_types_by_name['QueryRedelegationsResponse']
_QUERYDELEGATORVALIDATORSREQUEST = DESCRIPTOR.message_types_by_name['QueryDelegatorValidatorsRequest']
_QUERYDELEGATORVALIDATORSRESPONSE = DESCRIPTOR.message_types_by_name['QueryDelegatorValidatorsResponse']
_QUERYDELEGATORVALIDATORREQUEST = DESCRIPTOR.message_types_by_name['QueryDelegatorValidatorRequest']
_QUERYDELEGATORVALIDATORRESPONSE = DESCRIPTOR.message_types_by_name['QueryDelegatorValidatorResponse']
_QUERYHISTORICALINFOREQUEST = DESCRIPTOR.message_types_by_name['QueryHistoricalInfoRequest']
_QUERYHISTORICALINFORESPONSE = DESCRIPTOR.message_types_by_name['QueryHistoricalInfoResponse']
_QUERYPOOLREQUEST = DESCRIPTOR.message_types_by_name['QueryPoolRequest']
_QUERYPOOLRESPONSE = DESCRIPTOR.message_types_by_name['QueryPoolResponse']
_QUERYPARAMSREQUEST = DESCRIPTOR.message_types_by_name['QueryParamsRequest']
_QUERYPARAMSRESPONSE = DESCRIPTOR.message_types_by_name['QueryParamsResponse']
QueryValidatorsRequest = _reflection.GeneratedProtocolMessageType('QueryValidatorsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYVALIDATORSREQUEST,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryValidatorsRequest)
  })
_sym_db.RegisterMessage(QueryValidatorsRequest)

QueryValidatorsResponse = _reflection.GeneratedProtocolMessageType('QueryValidatorsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYVALIDATORSRESPONSE,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryValidatorsResponse)
  })
_sym_db.RegisterMessage(QueryValidatorsResponse)

QueryValidatorRequest = _reflection.GeneratedProtocolMessageType('QueryValidatorRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYVALIDATORREQUEST,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryValidatorRequest)
  })
_sym_db.RegisterMessage(QueryValidatorRequest)

QueryValidatorResponse = _reflection.GeneratedProtocolMessageType('QueryValidatorResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYVALIDATORRESPONSE,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryValidatorResponse)
  })
_sym_db.RegisterMessage(QueryValidatorResponse)

QueryValidatorDelegationsRequest = _reflection.GeneratedProtocolMessageType('QueryValidatorDelegationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYVALIDATORDELEGATIONSREQUEST,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryValidatorDelegationsRequest)
  })
_sym_db.RegisterMessage(QueryValidatorDelegationsRequest)

QueryValidatorDelegationsResponse = _reflection.GeneratedProtocolMessageType('QueryValidatorDelegationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYVALIDATORDELEGATIONSRESPONSE,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryValidatorDelegationsResponse)
  })
_sym_db.RegisterMessage(QueryValidatorDelegationsResponse)

QueryValidatorUnbondingDelegationsRequest = _reflection.GeneratedProtocolMessageType('QueryValidatorUnbondingDelegationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYVALIDATORUNBONDINGDELEGATIONSREQUEST,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryValidatorUnbondingDelegationsRequest)
  })
_sym_db.RegisterMessage(QueryValidatorUnbondingDelegationsRequest)

QueryValidatorUnbondingDelegationsResponse = _reflection.GeneratedProtocolMessageType('QueryValidatorUnbondingDelegationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYVALIDATORUNBONDINGDELEGATIONSRESPONSE,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryValidatorUnbondingDelegationsResponse)
  })
_sym_db.RegisterMessage(QueryValidatorUnbondingDelegationsResponse)

QueryDelegationRequest = _reflection.GeneratedProtocolMessageType('QueryDelegationRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYDELEGATIONREQUEST,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryDelegationRequest)
  })
_sym_db.RegisterMessage(QueryDelegationRequest)

QueryDelegationResponse = _reflection.GeneratedProtocolMessageType('QueryDelegationResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYDELEGATIONRESPONSE,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryDelegationResponse)
  })
_sym_db.RegisterMessage(QueryDelegationResponse)

QueryUnbondingDelegationRequest = _reflection.GeneratedProtocolMessageType('QueryUnbondingDelegationRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYUNBONDINGDELEGATIONREQUEST,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryUnbondingDelegationRequest)
  })
_sym_db.RegisterMessage(QueryUnbondingDelegationRequest)

QueryUnbondingDelegationResponse = _reflection.GeneratedProtocolMessageType('QueryUnbondingDelegationResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYUNBONDINGDELEGATIONRESPONSE,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryUnbondingDelegationResponse)
  })
_sym_db.RegisterMessage(QueryUnbondingDelegationResponse)

QueryDelegatorDelegationsRequest = _reflection.GeneratedProtocolMessageType('QueryDelegatorDelegationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYDELEGATORDELEGATIONSREQUEST,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryDelegatorDelegationsRequest)
  })
_sym_db.RegisterMessage(QueryDelegatorDelegationsRequest)

QueryDelegatorDelegationsResponse = _reflection.GeneratedProtocolMessageType('QueryDelegatorDelegationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYDELEGATORDELEGATIONSRESPONSE,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryDelegatorDelegationsResponse)
  })
_sym_db.RegisterMessage(QueryDelegatorDelegationsResponse)

QueryDelegatorUnbondingDelegationsRequest = _reflection.GeneratedProtocolMessageType('QueryDelegatorUnbondingDelegationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYDELEGATORUNBONDINGDELEGATIONSREQUEST,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryDelegatorUnbondingDelegationsRequest)
  })
_sym_db.RegisterMessage(QueryDelegatorUnbondingDelegationsRequest)

QueryDelegatorUnbondingDelegationsResponse = _reflection.GeneratedProtocolMessageType('QueryDelegatorUnbondingDelegationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYDELEGATORUNBONDINGDELEGATIONSRESPONSE,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryDelegatorUnbondingDelegationsResponse)
  })
_sym_db.RegisterMessage(QueryDelegatorUnbondingDelegationsResponse)

QueryRedelegationsRequest = _reflection.GeneratedProtocolMessageType('QueryRedelegationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYREDELEGATIONSREQUEST,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryRedelegationsRequest)
  })
_sym_db.RegisterMessage(QueryRedelegationsRequest)

QueryRedelegationsResponse = _reflection.GeneratedProtocolMessageType('QueryRedelegationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYREDELEGATIONSRESPONSE,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryRedelegationsResponse)
  })
_sym_db.RegisterMessage(QueryRedelegationsResponse)

QueryDelegatorValidatorsRequest = _reflection.GeneratedProtocolMessageType('QueryDelegatorValidatorsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYDELEGATORVALIDATORSREQUEST,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryDelegatorValidatorsRequest)
  })
_sym_db.RegisterMessage(QueryDelegatorValidatorsRequest)

QueryDelegatorValidatorsResponse = _reflection.GeneratedProtocolMessageType('QueryDelegatorValidatorsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYDELEGATORVALIDATORSRESPONSE,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryDelegatorValidatorsResponse)
  })
_sym_db.RegisterMessage(QueryDelegatorValidatorsResponse)

QueryDelegatorValidatorRequest = _reflection.GeneratedProtocolMessageType('QueryDelegatorValidatorRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYDELEGATORVALIDATORREQUEST,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryDelegatorValidatorRequest)
  })
_sym_db.RegisterMessage(QueryDelegatorValidatorRequest)

QueryDelegatorValidatorResponse = _reflection.GeneratedProtocolMessageType('QueryDelegatorValidatorResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYDELEGATORVALIDATORRESPONSE,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryDelegatorValidatorResponse)
  })
_sym_db.RegisterMessage(QueryDelegatorValidatorResponse)

QueryHistoricalInfoRequest = _reflection.GeneratedProtocolMessageType('QueryHistoricalInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYHISTORICALINFOREQUEST,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryHistoricalInfoRequest)
  })
_sym_db.RegisterMessage(QueryHistoricalInfoRequest)

QueryHistoricalInfoResponse = _reflection.GeneratedProtocolMessageType('QueryHistoricalInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYHISTORICALINFORESPONSE,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryHistoricalInfoResponse)
  })
_sym_db.RegisterMessage(QueryHistoricalInfoResponse)

QueryPoolRequest = _reflection.GeneratedProtocolMessageType('QueryPoolRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPOOLREQUEST,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryPoolRequest)
  })
_sym_db.RegisterMessage(QueryPoolRequest)

QueryPoolResponse = _reflection.GeneratedProtocolMessageType('QueryPoolResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPOOLRESPONSE,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryPoolResponse)
  })
_sym_db.RegisterMessage(QueryPoolResponse)

QueryParamsRequest = _reflection.GeneratedProtocolMessageType('QueryParamsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPARAMSREQUEST,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryParamsRequest)
  })
_sym_db.RegisterMessage(QueryParamsRequest)

QueryParamsResponse = _reflection.GeneratedProtocolMessageType('QueryParamsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPARAMSRESPONSE,
  '__module__' : 'cosmos.staking.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.staking.v1beta1.QueryParamsResponse)
  })
_sym_db.RegisterMessage(QueryParamsResponse)

_QUERY = DESCRIPTOR.services_by_name['Query']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z,github.com/cosmos/cosmos-sdk/x/staking/types'
  _QUERYVALIDATORSRESPONSE.fields_by_name['validators']._options = None
  _QUERYVALIDATORSRESPONSE.fields_by_name['validators']._serialized_options = b'\310\336\037\000'
  _QUERYVALIDATORRESPONSE.fields_by_name['validator']._options = None
  _QUERYVALIDATORRESPONSE.fields_by_name['validator']._serialized_options = b'\310\336\037\000'
  _QUERYVALIDATORDELEGATIONSRESPONSE.fields_by_name['delegation_responses']._options = None
  _QUERYVALIDATORDELEGATIONSRESPONSE.fields_by_name['delegation_responses']._serialized_options = b'\310\336\037\000\252\337\037\023DelegationResponses'
  _QUERYVALIDATORUNBONDINGDELEGATIONSRESPONSE.fields_by_name['unbonding_responses']._options = None
  _QUERYVALIDATORUNBONDINGDELEGATIONSRESPONSE.fields_by_name['unbonding_responses']._serialized_options = b'\310\336\037\000'
  _QUERYDELEGATIONREQUEST._options = None
  _QUERYDELEGATIONREQUEST._serialized_options = b'\350\240\037\000\210\240\037\000'
  _QUERYUNBONDINGDELEGATIONREQUEST._options = None
  _QUERYUNBONDINGDELEGATIONREQUEST._serialized_options = b'\350\240\037\000\210\240\037\000'
  _QUERYUNBONDINGDELEGATIONRESPONSE.fields_by_name['unbond']._options = None
  _QUERYUNBONDINGDELEGATIONRESPONSE.fields_by_name['unbond']._serialized_options = b'\310\336\037\000'
  _QUERYDELEGATORDELEGATIONSREQUEST._options = None
  _QUERYDELEGATORDELEGATIONSREQUEST._serialized_options = b'\350\240\037\000\210\240\037\000'
  _QUERYDELEGATORDELEGATIONSRESPONSE.fields_by_name['delegation_responses']._options = None
  _QUERYDELEGATORDELEGATIONSRESPONSE.fields_by_name['delegation_responses']._serialized_options = b'\310\336\037\000'
  _QUERYDELEGATORUNBONDINGDELEGATIONSREQUEST._options = None
  _QUERYDELEGATORUNBONDINGDELEGATIONSREQUEST._serialized_options = b'\350\240\037\000\210\240\037\000'
  _QUERYDELEGATORUNBONDINGDELEGATIONSRESPONSE.fields_by_name['unbonding_responses']._options = None
  _QUERYDELEGATORUNBONDINGDELEGATIONSRESPONSE.fields_by_name['unbonding_responses']._serialized_options = b'\310\336\037\000'
  _QUERYREDELEGATIONSREQUEST._options = None
  _QUERYREDELEGATIONSREQUEST._serialized_options = b'\350\240\037\000\210\240\037\000'
  _QUERYREDELEGATIONSRESPONSE.fields_by_name['redelegation_responses']._options = None
  _QUERYREDELEGATIONSRESPONSE.fields_by_name['redelegation_responses']._serialized_options = b'\310\336\037\000'
  _QUERYDELEGATORVALIDATORSREQUEST._options = None
  _QUERYDELEGATORVALIDATORSREQUEST._serialized_options = b'\350\240\037\000\210\240\037\000'
  _QUERYDELEGATORVALIDATORSRESPONSE.fields_by_name['validators']._options = None
  _QUERYDELEGATORVALIDATORSRESPONSE.fields_by_name['validators']._serialized_options = b'\310\336\037\000'
  _QUERYDELEGATORVALIDATORREQUEST._options = None
  _QUERYDELEGATORVALIDATORREQUEST._serialized_options = b'\350\240\037\000\210\240\037\000'
  _QUERYDELEGATORVALIDATORRESPONSE.fields_by_name['validator']._options = None
  _QUERYDELEGATORVALIDATORRESPONSE.fields_by_name['validator']._serialized_options = b'\310\336\037\000'
  _QUERYPOOLRESPONSE.fields_by_name['pool']._options = None
  _QUERYPOOLRESPONSE.fields_by_name['pool']._serialized_options = b'\310\336\037\000'
  _QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
  _QUERYPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _QUERY.methods_by_name['Validators']._options = None
  _QUERY.methods_by_name['Validators']._serialized_options = b'\202\323\344\223\002$\022\"/cosmos/staking/v1beta1/validators'
  _QUERY.methods_by_name['Validator']._options = None
  _QUERY.methods_by_name['Validator']._serialized_options = b'\202\323\344\223\0025\0223/cosmos/staking/v1beta1/validators/{validator_addr}'
  _QUERY.methods_by_name['ValidatorDelegations']._options = None
  _QUERY.methods_by_name['ValidatorDelegations']._serialized_options = b'\202\323\344\223\002A\022?/cosmos/staking/v1beta1/validators/{validator_addr}/delegations'
  _QUERY.methods_by_name['ValidatorUnbondingDelegations']._options = None
  _QUERY.methods_by_name['ValidatorUnbondingDelegations']._serialized_options = b'\202\323\344\223\002K\022I/cosmos/staking/v1beta1/validators/{validator_addr}/unbonding_delegations'
  _QUERY.methods_by_name['Delegation']._options = None
  _QUERY.methods_by_name['Delegation']._serialized_options = b'\202\323\344\223\002R\022P/cosmos/staking/v1beta1/validators/{validator_addr}/delegations/{delegator_addr}'
  _QUERY.methods_by_name['UnbondingDelegation']._options = None
  _QUERY.methods_by_name['UnbondingDelegation']._serialized_options = b'\202\323\344\223\002g\022e/cosmos/staking/v1beta1/validators/{validator_addr}/delegations/{delegator_addr}/unbonding_delegation'
  _QUERY.methods_by_name['DelegatorDelegations']._options = None
  _QUERY.methods_by_name['DelegatorDelegations']._serialized_options = b'\202\323\344\223\0026\0224/cosmos/staking/v1beta1/delegations/{delegator_addr}'
  _QUERY.methods_by_name['DelegatorUnbondingDelegations']._options = None
  _QUERY.methods_by_name['DelegatorUnbondingDelegations']._serialized_options = b'\202\323\344\223\002K\022I/cosmos/staking/v1beta1/delegators/{delegator_addr}/unbonding_delegations'
  _QUERY.methods_by_name['Redelegations']._options = None
  _QUERY.methods_by_name['Redelegations']._serialized_options = b'\202\323\344\223\002C\022A/cosmos/staking/v1beta1/delegators/{delegator_addr}/redelegations'
  _QUERY.methods_by_name['DelegatorValidators']._options = None
  _QUERY.methods_by_name['DelegatorValidators']._serialized_options = b'\202\323\344\223\002@\022>/cosmos/staking/v1beta1/delegators/{delegator_addr}/validators'
  _QUERY.methods_by_name['DelegatorValidator']._options = None
  _QUERY.methods_by_name['DelegatorValidator']._serialized_options = b'\202\323\344\223\002Q\022O/cosmos/staking/v1beta1/delegators/{delegator_addr}/validators/{validator_addr}'
  _QUERY.methods_by_name['HistoricalInfo']._options = None
  _QUERY.methods_by_name['HistoricalInfo']._serialized_options = b'\202\323\344\223\0022\0220/cosmos/staking/v1beta1/historical_info/{height}'
  _QUERY.methods_by_name['Pool']._options = None
  _QUERY.methods_by_name['Pool']._serialized_options = b'\202\323\344\223\002\036\022\034/cosmos/staking/v1beta1/pool'
  _QUERY.methods_by_name['Params']._options = None
  _QUERY.methods_by_name['Params']._serialized_options = b'\202\323\344\223\002 \022\036/cosmos/staking/v1beta1/params'
  _QUERYVALIDATORSREQUEST._serialized_start=196
  _QUERYVALIDATORSREQUEST._serialized_end=296
  _QUERYVALIDATORSRESPONSE._serialized_start=299
  _QUERYVALIDATORSRESPONSE._serialized_end=446
  _QUERYVALIDATORREQUEST._serialized_start=448
  _QUERYVALIDATORREQUEST._serialized_end=495
  _QUERYVALIDATORRESPONSE._serialized_start=497
  _QUERYVALIDATORRESPONSE._serialized_end=581
  _QUERYVALIDATORDELEGATIONSREQUEST._serialized_start=583
  _QUERYVALIDATORDELEGATIONSREQUEST._serialized_end=701
  _QUERYVALIDATORDELEGATIONSRESPONSE._serialized_start=704
  _QUERYVALIDATORDELEGATIONSRESPONSE._serialized_end=903
  _QUERYVALIDATORUNBONDINGDELEGATIONSREQUEST._serialized_start=905
  _QUERYVALIDATORUNBONDINGDELEGATIONSREQUEST._serialized_end=1032
  _QUERYVALIDATORUNBONDINGDELEGATIONSRESPONSE._serialized_start=1035
  _QUERYVALIDATORUNBONDINGDELEGATIONSRESPONSE._serialized_end=1220
  _QUERYDELEGATIONREQUEST._serialized_start=1222
  _QUERYDELEGATIONREQUEST._serialized_end=1304
  _QUERYDELEGATIONRESPONSE._serialized_start=1306
  _QUERYDELEGATIONRESPONSE._serialized_end=1404
  _QUERYUNBONDINGDELEGATIONREQUEST._serialized_start=1406
  _QUERYUNBONDINGDELEGATIONREQUEST._serialized_end=1497
  _QUERYUNBONDINGDELEGATIONRESPONSE._serialized_start=1499
  _QUERYUNBONDINGDELEGATIONRESPONSE._serialized_end=1600
  _QUERYDELEGATORDELEGATIONSREQUEST._serialized_start=1603
  _QUERYDELEGATORDELEGATIONSREQUEST._serialized_end=1731
  _QUERYDELEGATORDELEGATIONSRESPONSE._serialized_start=1734
  _QUERYDELEGATORDELEGATIONSRESPONSE._serialized_end=1910
  _QUERYDELEGATORUNBONDINGDELEGATIONSREQUEST._serialized_start=1913
  _QUERYDELEGATORUNBONDINGDELEGATIONSREQUEST._serialized_end=2050
  _QUERYDELEGATORUNBONDINGDELEGATIONSRESPONSE._serialized_start=2053
  _QUERYDELEGATORUNBONDINGDELEGATIONSRESPONSE._serialized_end=2238
  _QUERYREDELEGATIONSREQUEST._serialized_start=2241
  _QUERYREDELEGATIONSREQUEST._serialized_end=2418
  _QUERYREDELEGATIONSRESPONSE._serialized_start=2421
  _QUERYREDELEGATIONSRESPONSE._serialized_end=2594
  _QUERYDELEGATORVALIDATORSREQUEST._serialized_start=2596
  _QUERYDELEGATORVALIDATORSREQUEST._serialized_end=2723
  _QUERYDELEGATORVALIDATORSRESPONSE._serialized_start=2726
  _QUERYDELEGATORVALIDATORSRESPONSE._serialized_end=2882
  _QUERYDELEGATORVALIDATORREQUEST._serialized_start=2884
  _QUERYDELEGATORVALIDATORREQUEST._serialized_end=2974
  _QUERYDELEGATORVALIDATORRESPONSE._serialized_start=2976
  _QUERYDELEGATORVALIDATORRESPONSE._serialized_end=3069
  _QUERYHISTORICALINFOREQUEST._serialized_start=3071
  _QUERYHISTORICALINFOREQUEST._serialized_end=3115
  _QUERYHISTORICALINFORESPONSE._serialized_start=3117
  _QUERYHISTORICALINFORESPONSE._serialized_end=3200
  _QUERYPOOLREQUEST._serialized_start=3202
  _QUERYPOOLREQUEST._serialized_end=3220
  _QUERYPOOLRESPONSE._serialized_start=3222
  _QUERYPOOLRESPONSE._serialized_end=3291
  _QUERYPARAMSREQUEST._serialized_start=3293
  _QUERYPARAMSREQUEST._serialized_end=3313
  _QUERYPARAMSRESPONSE._serialized_start=3315
  _QUERYPARAMSRESPONSE._serialized_end=3390
  _QUERY._serialized_start=3393
  _QUERY._serialized_end=6187
# @@protoc_insertion_point(module_scope)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Note: To use the 'upload' functionality of this file, you must:
#   $ pipenv install twine --dev

import io
import os
import sys
from shutil import rmtree

from setuptools import Command, find_packages, setup

NAME = "nibiru-py"
DESCRIPTION = "Nibiru Python SDK"
URL = "https://github.com/NibiruChain/sdk-python"
EMAIL = "dev@nibiru.fi"
AUTHOR = "Nibiru Chain"
REQUIRES_PYTHON = ">=3.7.0"
VERSION = "0.0.6"

REQUIRED = [
    "grpcio",
    "asyncio",
    "aiohttp",
    "ecdsa",
    "bech32",
    "mnemonic",
    "hdwallets",
    "pysha3",
    "protobuf",
    "grpcio-tools",
    "bip32",
    "requests",
    "eip712_structs",
    "coincurve",
    "aiocron",
]

# The rest you shouldn't have to touch too much :)
# ------------------------------------------------
# Except, perhaps the License and Trove Classifiers!
# If you do change the License, remember to change the Trove Classifier for that!

here = os.path.abspath(os.path.dirname(__file__))

# Import the README and use it as the long-description.
# Note: this will only work if 'README.md' is present in your MANIFEST.in file!
try:
    with io.open(os.path.join(here, "README.md"), encoding="utf-8") as f:
        long_description = "\n" + f.read()
except FileNotFoundError:
    long_description = DESCRIPTION

# Load the package's __version__.py module as a dictionary.
about = {}
if not VERSION:
    project_slug = NAME.lower().replace("-", "_").replace(" ", "_")
    with open(os.path.join(here, project_slug, "__version__.py")) as f:
        exec(f.read(), about)
else:
    about["__version__"] = VERSION


class UploadCommand(Command):
    """Support setup.py upload."""

    description = "Build and publish the package."
    user_options = []

    @staticmethod
    def status(s):
        """Prints things in bold."""
        print("\033[1m{0}\033[0m".format(s))

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        try:
            self.status("Removing previous builds…")
            rmtree(os.path.join(here, "dist"))
        except OSError:
            pass

        self.status("Building Source and Wheel (universal) distribution…")
        os.system("{0} setup.py sdist bdist_wheel --universal".format(sys.executable))

        self.status("Uploading the package to PyPI via Twine…")
        os.system("twine upload dist/*")

        self.status("Pushing git tags…")
        os.system("git tag v{0}".format(about["__version__"]))
        os.system("git push --tags")

        sys.exit()


# Where the magic happens:
setup(
    name=NAME,
    packages=find_packages(),
    include_package_data=True,
    version=about["__version__"],
    license="Apache Software License 2.0",
    description=DESCRIPTION,
    long_description=long_description,
    long_description_content_type="text/markdown",
    author=AUTHOR,
    author_email=EMAIL,
    python_requires=REQUIRES_PYTHON,
    url=URL,
    install_requires=REQUIRED,
    classifiers=[
        # Trove classifiers
        # Full list: https://pypi.python.org/pypi?%3Aaction=list_classifiers
        "License :: OSI Approved :: Apache Software License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: Implementation :: CPython",
        "Programming Language :: Python :: Implementation :: PyPy",
    ],
    # $ setup.py publish support.
    cmdclass={
        "upload": UploadCommand,
    },
)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/tx/v1beta1/service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from cosmos.base.abci.v1beta1 import abci_pb2 as cosmos_dot_base_dot_abci_dot_v1beta1_dot_abci__pb2
from cosmos.tx.v1beta1 import tx_pb2 as cosmos_dot_tx_dot_v1beta1_dot_tx__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from tendermint.types import block_pb2 as tendermint_dot_types_dot_block__pb2
from tendermint.types import types_pb2 as tendermint_dot_types_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x63osmos/tx/v1beta1/service.proto\x12\x11\x63osmos.tx.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a#cosmos/base/abci/v1beta1/abci.proto\x1a\x1a\x63osmos/tx/v1beta1/tx.proto\x1a\x14gogoproto/gogo.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x1ctendermint/types/block.proto\x1a\x1ctendermint/types/types.proto\"\x8e\x01\n\x12GetTxsEventRequest\x12\x0e\n\x06\x65vents\x18\x01 \x03(\t\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\x12,\n\x08order_by\x18\x03 \x01(\x0e\x32\x1a.cosmos.tx.v1beta1.OrderBy\"\xb2\x01\n\x13GetTxsEventResponse\x12\"\n\x03txs\x18\x01 \x03(\x0b\x32\x15.cosmos.tx.v1beta1.Tx\x12:\n\x0ctx_responses\x18\x02 \x03(\x0b\x32$.cosmos.base.abci.v1beta1.TxResponse\x12;\n\npagination\x18\x03 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"V\n\x12\x42roadcastTxRequest\x12\x10\n\x08tx_bytes\x18\x01 \x01(\x0c\x12.\n\x04mode\x18\x02 \x01(\x0e\x32 .cosmos.tx.v1beta1.BroadcastMode\"P\n\x13\x42roadcastTxResponse\x12\x39\n\x0btx_response\x18\x01 \x01(\x0b\x32$.cosmos.base.abci.v1beta1.TxResponse\"J\n\x0fSimulateRequest\x12%\n\x02tx\x18\x01 \x01(\x0b\x32\x15.cosmos.tx.v1beta1.TxB\x02\x18\x01\x12\x10\n\x08tx_bytes\x18\x02 \x01(\x0c\"y\n\x10SimulateResponse\x12\x33\n\x08gas_info\x18\x01 \x01(\x0b\x32!.cosmos.base.abci.v1beta1.GasInfo\x12\x30\n\x06result\x18\x02 \x01(\x0b\x32 .cosmos.base.abci.v1beta1.Result\"\x1c\n\x0cGetTxRequest\x12\x0c\n\x04hash\x18\x01 \x01(\t\"m\n\rGetTxResponse\x12!\n\x02tx\x18\x01 \x01(\x0b\x32\x15.cosmos.tx.v1beta1.Tx\x12\x39\n\x0btx_response\x18\x02 \x01(\x0b\x32$.cosmos.base.abci.v1beta1.TxResponse\"d\n\x16GetBlockWithTxsRequest\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\xcf\x01\n\x17GetBlockWithTxsResponse\x12\"\n\x03txs\x18\x01 \x03(\x0b\x32\x15.cosmos.tx.v1beta1.Tx\x12+\n\x08\x62lock_id\x18\x02 \x01(\x0b\x32\x19.tendermint.types.BlockID\x12&\n\x05\x62lock\x18\x03 \x01(\x0b\x32\x17.tendermint.types.Block\x12;\n\npagination\x18\x04 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse*H\n\x07OrderBy\x12\x18\n\x14ORDER_BY_UNSPECIFIED\x10\x00\x12\x10\n\x0cORDER_BY_ASC\x10\x01\x12\x11\n\rORDER_BY_DESC\x10\x02*|\n\rBroadcastMode\x12\x1e\n\x1a\x42ROADCAST_MODE_UNSPECIFIED\x10\x00\x12\x18\n\x14\x42ROADCAST_MODE_BLOCK\x10\x01\x12\x17\n\x13\x42ROADCAST_MODE_SYNC\x10\x02\x12\x18\n\x14\x42ROADCAST_MODE_ASYNC\x10\x03\x32\x92\x05\n\x07Service\x12{\n\x08Simulate\x12\".cosmos.tx.v1beta1.SimulateRequest\x1a#.cosmos.tx.v1beta1.SimulateResponse\"&\x82\xd3\xe4\x93\x02 \"\x1b/cosmos/tx/v1beta1/simulate:\x01*\x12q\n\x05GetTx\x12\x1f.cosmos.tx.v1beta1.GetTxRequest\x1a .cosmos.tx.v1beta1.GetTxResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/cosmos/tx/v1beta1/txs/{hash}\x12\x7f\n\x0b\x42roadcastTx\x12%.cosmos.tx.v1beta1.BroadcastTxRequest\x1a&.cosmos.tx.v1beta1.BroadcastTxResponse\"!\x82\xd3\xe4\x93\x02\x1b\"\x16/cosmos/tx/v1beta1/txs:\x01*\x12|\n\x0bGetTxsEvent\x12%.cosmos.tx.v1beta1.GetTxsEventRequest\x1a&.cosmos.tx.v1beta1.GetTxsEventResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/cosmos/tx/v1beta1/txs\x12\x97\x01\n\x0fGetBlockWithTxs\x12).cosmos.tx.v1beta1.GetBlockWithTxsRequest\x1a*.cosmos.tx.v1beta1.GetBlockWithTxsResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/cosmos/tx/v1beta1/txs/block/{height}B+Z%github.com/cosmos/cosmos-sdk/types/tx\xc0\xe3\x1e\x01\x62\x06proto3')

_ORDERBY = DESCRIPTOR.enum_types_by_name['OrderBy']
OrderBy = enum_type_wrapper.EnumTypeWrapper(_ORDERBY)
_BROADCASTMODE = DESCRIPTOR.enum_types_by_name['BroadcastMode']
BroadcastMode = enum_type_wrapper.EnumTypeWrapper(_BROADCASTMODE)
ORDER_BY_UNSPECIFIED = 0
ORDER_BY_ASC = 1
ORDER_BY_DESC = 2
BROADCAST_MODE_UNSPECIFIED = 0
BROADCAST_MODE_BLOCK = 1
BROADCAST_MODE_SYNC = 2
BROADCAST_MODE_ASYNC = 3


_GETTXSEVENTREQUEST = DESCRIPTOR.message_types_by_name['GetTxsEventRequest']
_GETTXSEVENTRESPONSE = DESCRIPTOR.message_types_by_name['GetTxsEventResponse']
_BROADCASTTXREQUEST = DESCRIPTOR.message_types_by_name['BroadcastTxRequest']
_BROADCASTTXRESPONSE = DESCRIPTOR.message_types_by_name['BroadcastTxResponse']
_SIMULATEREQUEST = DESCRIPTOR.message_types_by_name['SimulateRequest']
_SIMULATERESPONSE = DESCRIPTOR.message_types_by_name['SimulateResponse']
_GETTXREQUEST = DESCRIPTOR.message_types_by_name['GetTxRequest']
_GETTXRESPONSE = DESCRIPTOR.message_types_by_name['GetTxResponse']
_GETBLOCKWITHTXSREQUEST = DESCRIPTOR.message_types_by_name['GetBlockWithTxsRequest']
_GETBLOCKWITHTXSRESPONSE = DESCRIPTOR.message_types_by_name['GetBlockWithTxsResponse']
GetTxsEventRequest = _reflection.GeneratedProtocolMessageType('GetTxsEventRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTXSEVENTREQUEST,
  '__module__' : 'cosmos.tx.v1beta1.service_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.tx.v1beta1.GetTxsEventRequest)
  })
_sym_db.RegisterMessage(GetTxsEventRequest)

GetTxsEventResponse = _reflection.GeneratedProtocolMessageType('GetTxsEventResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTXSEVENTRESPONSE,
  '__module__' : 'cosmos.tx.v1beta1.service_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.tx.v1beta1.GetTxsEventResponse)
  })
_sym_db.RegisterMessage(GetTxsEventResponse)

BroadcastTxRequest = _reflection.GeneratedProtocolMessageType('BroadcastTxRequest', (_message.Message,), {
  'DESCRIPTOR' : _BROADCASTTXREQUEST,
  '__module__' : 'cosmos.tx.v1beta1.service_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.tx.v1beta1.BroadcastTxRequest)
  })
_sym_db.RegisterMessage(BroadcastTxRequest)

BroadcastTxResponse = _reflection.GeneratedProtocolMessageType('BroadcastTxResponse', (_message.Message,), {
  'DESCRIPTOR' : _BROADCASTTXRESPONSE,
  '__module__' : 'cosmos.tx.v1beta1.service_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.tx.v1beta1.BroadcastTxResponse)
  })
_sym_db.RegisterMessage(BroadcastTxResponse)

SimulateRequest = _reflection.GeneratedProtocolMessageType('SimulateRequest', (_message.Message,), {
  'DESCRIPTOR' : _SIMULATEREQUEST,
  '__module__' : 'cosmos.tx.v1beta1.service_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.tx.v1beta1.SimulateRequest)
  })
_sym_db.RegisterMessage(SimulateRequest)

SimulateResponse = _reflection.GeneratedProtocolMessageType('SimulateResponse', (_message.Message,), {
  'DESCRIPTOR' : _SIMULATERESPONSE,
  '__module__' : 'cosmos.tx.v1beta1.service_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.tx.v1beta1.SimulateResponse)
  })
_sym_db.RegisterMessage(SimulateResponse)

GetTxRequest = _reflection.GeneratedProtocolMessageType('GetTxRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTXREQUEST,
  '__module__' : 'cosmos.tx.v1beta1.service_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.tx.v1beta1.GetTxRequest)
  })
_sym_db.RegisterMessage(GetTxRequest)

GetTxResponse = _reflection.GeneratedProtocolMessageType('GetTxResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTXRESPONSE,
  '__module__' : 'cosmos.tx.v1beta1.service_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.tx.v1beta1.GetTxResponse)
  })
_sym_db.RegisterMessage(GetTxResponse)

GetBlockWithTxsRequest = _reflection.GeneratedProtocolMessageType('GetBlockWithTxsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBLOCKWITHTXSREQUEST,
  '__module__' : 'cosmos.tx.v1beta1.service_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.tx.v1beta1.GetBlockWithTxsRequest)
  })
_sym_db.RegisterMessage(GetBlockWithTxsRequest)

GetBlockWithTxsResponse = _reflection.GeneratedProtocolMessageType('GetBlockWithTxsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETBLOCKWITHTXSRESPONSE,
  '__module__' : 'cosmos.tx.v1beta1.service_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.tx.v1beta1.GetBlockWithTxsResponse)
  })
_sym_db.RegisterMessage(GetBlockWithTxsResponse)

_SERVICE = DESCRIPTOR.services_by_name['Service']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z%github.com/cosmos/cosmos-sdk/types/tx\300\343\036\001'
  _SIMULATEREQUEST.fields_by_name['tx']._options = None
  _SIMULATEREQUEST.fields_by_name['tx']._serialized_options = b'\030\001'
  _SERVICE.methods_by_name['Simulate']._options = None
  _SERVICE.methods_by_name['Simulate']._serialized_options = b'\202\323\344\223\002 \"\033/cosmos/tx/v1beta1/simulate:\001*'
  _SERVICE.methods_by_name['GetTx']._options = None
  _SERVICE.methods_by_name['GetTx']._serialized_options = b'\202\323\344\223\002\037\022\035/cosmos/tx/v1beta1/txs/{hash}'
  _SERVICE.methods_by_name['BroadcastTx']._options = None
  _SERVICE.methods_by_name['BroadcastTx']._serialized_options = b'\202\323\344\223\002\033\"\026/cosmos/tx/v1beta1/txs:\001*'
  _SERVICE.methods_by_name['GetTxsEvent']._options = None
  _SERVICE.methods_by_name['GetTxsEvent']._serialized_options = b'\202\323\344\223\002\030\022\026/cosmos/tx/v1beta1/txs'
  _SERVICE.methods_by_name['GetBlockWithTxs']._options = None
  _SERVICE.methods_by_name['GetBlockWithTxs']._serialized_options = b'\202\323\344\223\002\'\022%/cosmos/tx/v1beta1/txs/block/{height}'
  _ORDERBY._serialized_start=1423
  _ORDERBY._serialized_end=1495
  _BROADCASTMODE._serialized_start=1497
  _BROADCASTMODE._serialized_end=1621
  _GETTXSEVENTREQUEST._serialized_start=276
  _GETTXSEVENTREQUEST._serialized_end=418
  _GETTXSEVENTRESPONSE._serialized_start=421
  _GETTXSEVENTRESPONSE._serialized_end=599
  _BROADCASTTXREQUEST._serialized_start=601
  _BROADCASTTXREQUEST._serialized_end=687
  _BROADCASTTXRESPONSE._serialized_start=689
  _BROADCASTTXRESPONSE._serialized_end=769
  _SIMULATEREQUEST._serialized_start=771
  _SIMULATEREQUEST._serialized_end=845
  _SIMULATERESPONSE._serialized_start=847
  _SIMULATERESPONSE._serialized_end=968
  _GETTXREQUEST._serialized_start=970
  _GETTXREQUEST._serialized_end=998
  _GETTXRESPONSE._serialized_start=1000
  _GETTXRESPONSE._serialized_end=1109
  _GETBLOCKWITHTXSREQUEST._serialized_start=1111
  _GETBLOCKWITHTXSREQUEST._serialized_end=1211
  _GETBLOCKWITHTXSRESPONSE._serialized_start=1214
  _GETBLOCKWITHTXSRESPONSE._serialized_end=1421
  _SERVICE._serialized_start=1624
  _SERVICE._serialized_end=2282
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pricefeed/tx.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12pricefeed/tx.proto\x12\x13nibiru.pricefeed.v1\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/api/annotations.proto\"\xb7\x01\n\x0cMsgPostPrice\x12\x0c\n\x04\x66rom\x18\x01 \x01(\t\x12\x0e\n\x06token0\x18\x02 \x01(\t\x12\x0e\n\x06token1\x18\x03 \x01(\t\x12=\n\x05price\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x34\n\x06\x65xpiry\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\x90\xdf\x1f\x01\xc8\xde\x1f\x00:\x04\x88\xa0\x1f\x00\"\x16\n\x14MsgPostPriceResponse\"\xb3\x01\n\x16\x45ventOracleUpdatePrice\x12\x0f\n\x07pair_id\x18\x01 \x01(\t\x12\x0e\n\x06oracle\x18\x02 \x01(\t\x12\x42\n\npair_price\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x34\n\x06\x65xpiry\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\x90\xdf\x1f\x01\xc8\xde\x1f\x00\"l\n\x15\x45ventPairPriceUpdated\x12\x0f\n\x07pair_id\x18\x01 \x01(\t\x12\x42\n\npair_price\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x32\x86\x01\n\x03Msg\x12\x7f\n\tPostPrice\x12!.nibiru.pricefeed.v1.MsgPostPrice\x1a).nibiru.pricefeed.v1.MsgPostPriceResponse\"$\x82\xd3\xe4\x93\x02\x1e\"\x1c/nibiru/pricefeed/post-priceB9Z/github.com/NibiruChain/nibiru/x/pricefeed/types\xa8\xe2\x1e\x01\xe0\xe1\x1e\x01\x62\x06proto3')



_MSGPOSTPRICE = DESCRIPTOR.message_types_by_name['MsgPostPrice']
_MSGPOSTPRICERESPONSE = DESCRIPTOR.message_types_by_name['MsgPostPriceResponse']
_EVENTORACLEUPDATEPRICE = DESCRIPTOR.message_types_by_name['EventOracleUpdatePrice']
_EVENTPAIRPRICEUPDATED = DESCRIPTOR.message_types_by_name['EventPairPriceUpdated']
MsgPostPrice = _reflection.GeneratedProtocolMessageType('MsgPostPrice', (_message.Message,), {
  'DESCRIPTOR' : _MSGPOSTPRICE,
  '__module__' : 'pricefeed.tx_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.pricefeed.v1.MsgPostPrice)
  })
_sym_db.RegisterMessage(MsgPostPrice)

MsgPostPriceResponse = _reflection.GeneratedProtocolMessageType('MsgPostPriceResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGPOSTPRICERESPONSE,
  '__module__' : 'pricefeed.tx_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.pricefeed.v1.MsgPostPriceResponse)
  })
_sym_db.RegisterMessage(MsgPostPriceResponse)

EventOracleUpdatePrice = _reflection.GeneratedProtocolMessageType('EventOracleUpdatePrice', (_message.Message,), {
  'DESCRIPTOR' : _EVENTORACLEUPDATEPRICE,
  '__module__' : 'pricefeed.tx_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.pricefeed.v1.EventOracleUpdatePrice)
  })
_sym_db.RegisterMessage(EventOracleUpdatePrice)

EventPairPriceUpdated = _reflection.GeneratedProtocolMessageType('EventPairPriceUpdated', (_message.Message,), {
  'DESCRIPTOR' : _EVENTPAIRPRICEUPDATED,
  '__module__' : 'pricefeed.tx_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.pricefeed.v1.EventPairPriceUpdated)
  })
_sym_db.RegisterMessage(EventPairPriceUpdated)

_MSG = DESCRIPTOR.services_by_name['Msg']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z/github.com/NibiruChain/nibiru/x/pricefeed/types\250\342\036\001\340\341\036\001'
  _MSGPOSTPRICE.fields_by_name['price']._options = None
  _MSGPOSTPRICE.fields_by_name['price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MSGPOSTPRICE.fields_by_name['expiry']._options = None
  _MSGPOSTPRICE.fields_by_name['expiry']._serialized_options = b'\220\337\037\001\310\336\037\000'
  _MSGPOSTPRICE._options = None
  _MSGPOSTPRICE._serialized_options = b'\210\240\037\000'
  _EVENTORACLEUPDATEPRICE.fields_by_name['pair_price']._options = None
  _EVENTORACLEUPDATEPRICE.fields_by_name['pair_price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _EVENTORACLEUPDATEPRICE.fields_by_name['expiry']._options = None
  _EVENTORACLEUPDATEPRICE.fields_by_name['expiry']._serialized_options = b'\220\337\037\001\310\336\037\000'
  _EVENTPAIRPRICEUPDATED.fields_by_name['pair_price']._options = None
  _EVENTPAIRPRICEUPDATED.fields_by_name['pair_price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MSG.methods_by_name['PostPrice']._options = None
  _MSG.methods_by_name['PostPrice']._serialized_options = b'\202\323\344\223\002\036\"\034/nibiru/pricefeed/post-price'
  _MSGPOSTPRICE._serialized_start=129
  _MSGPOSTPRICE._serialized_end=312
  _MSGPOSTPRICERESPONSE._serialized_start=314
  _MSGPOSTPRICERESPONSE._serialized_end=336
  _EVENTORACLEUPDATEPRICE._serialized_start=339
  _EVENTORACLEUPDATEPRICE._serialized_end=518
  _EVENTPAIRPRICEUPDATED._serialized_start=520
  _EVENTPAIRPRICEUPDATED._serialized_end=628
  _MSG._serialized_start=631
  _MSG._serialized_end=765
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: stablecoin/tx.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13stablecoin/tx.proto\x12\x14nibiru.stablecoin.v1\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\"Q\n\rMsgMintStable\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12/\n\x06stable\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"\x8a\x02\n\x15MsgMintStableResponse\x12/\n\x06stable\x18\x01 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x12_\n\nused_coins\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12_\n\nfees_payed\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\"Q\n\rMsgBurnStable\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12/\n\x06stable\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"\xdb\x01\n\x15MsgBurnStableResponse\x12\x33\n\ncollateral\x18\x01 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x12,\n\x03gov\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x12_\n\nfees_payed\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\"T\n\x12MsgRecollateralize\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12-\n\x04\x63oll\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"J\n\x1aMsgRecollateralizeResponse\x12,\n\x03gov\x18\x01 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"K\n\nMsgBuyback\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12,\n\x03gov\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"C\n\x12MsgBuybackResponse\x12-\n\x04\x63oll\x18\x01 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x32\x9d\x04\n\x03Msg\x12\x82\x01\n\nMintStable\x12#.nibiru.stablecoin.v1.MsgMintStable\x1a+.nibiru.stablecoin.v1.MsgMintStableResponse\"\"\x82\xd3\xe4\x93\x02\x1c\"\x1a/nibiru/stablecoin/mint-sc\x12\x82\x01\n\nBurnStable\x12#.nibiru.stablecoin.v1.MsgBurnStable\x1a+.nibiru.stablecoin.v1.MsgBurnStableResponse\"\"\x82\xd3\xe4\x93\x02\x1c\"\x1a/nibiru/stablecoin/burn-sc\x12\x90\x01\n\x0fRecollateralize\x12(.nibiru.stablecoin.v1.MsgRecollateralize\x1a\x30.nibiru.stablecoin.v1.MsgRecollateralizeResponse\"!\x82\xd3\xe4\x93\x02\x1b\"\x19/nibiru/stablecoin/recoll\x12y\n\x07\x42uyback\x12 .nibiru.stablecoin.v1.MsgBuyback\x1a(.nibiru.stablecoin.v1.MsgBuybackResponse\"\"\x82\xd3\xe4\x93\x02\x1c\"\x1a/nibiru/stablecoin/buybackB2Z0github.com/NibiruChain/nibiru/x/stablecoin/typesb\x06proto3')



_MSGMINTSTABLE = DESCRIPTOR.message_types_by_name['MsgMintStable']
_MSGMINTSTABLERESPONSE = DESCRIPTOR.message_types_by_name['MsgMintStableResponse']
_MSGBURNSTABLE = DESCRIPTOR.message_types_by_name['MsgBurnStable']
_MSGBURNSTABLERESPONSE = DESCRIPTOR.message_types_by_name['MsgBurnStableResponse']
_MSGRECOLLATERALIZE = DESCRIPTOR.message_types_by_name['MsgRecollateralize']
_MSGRECOLLATERALIZERESPONSE = DESCRIPTOR.message_types_by_name['MsgRecollateralizeResponse']
_MSGBUYBACK = DESCRIPTOR.message_types_by_name['MsgBuyback']
_MSGBUYBACKRESPONSE = DESCRIPTOR.message_types_by_name['MsgBuybackResponse']
MsgMintStable = _reflection.GeneratedProtocolMessageType('MsgMintStable', (_message.Message,), {
  'DESCRIPTOR' : _MSGMINTSTABLE,
  '__module__' : 'stablecoin.tx_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.stablecoin.v1.MsgMintStable)
  })
_sym_db.RegisterMessage(MsgMintStable)

MsgMintStableResponse = _reflection.GeneratedProtocolMessageType('MsgMintStableResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGMINTSTABLERESPONSE,
  '__module__' : 'stablecoin.tx_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.stablecoin.v1.MsgMintStableResponse)
  })
_sym_db.RegisterMessage(MsgMintStableResponse)

MsgBurnStable = _reflection.GeneratedProtocolMessageType('MsgBurnStable', (_message.Message,), {
  'DESCRIPTOR' : _MSGBURNSTABLE,
  '__module__' : 'stablecoin.tx_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.stablecoin.v1.MsgBurnStable)
  })
_sym_db.RegisterMessage(MsgBurnStable)

MsgBurnStableResponse = _reflection.GeneratedProtocolMessageType('MsgBurnStableResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGBURNSTABLERESPONSE,
  '__module__' : 'stablecoin.tx_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.stablecoin.v1.MsgBurnStableResponse)
  })
_sym_db.RegisterMessage(MsgBurnStableResponse)

MsgRecollateralize = _reflection.GeneratedProtocolMessageType('MsgRecollateralize', (_message.Message,), {
  'DESCRIPTOR' : _MSGRECOLLATERALIZE,
  '__module__' : 'stablecoin.tx_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.stablecoin.v1.MsgRecollateralize)
  })
_sym_db.RegisterMessage(MsgRecollateralize)

MsgRecollateralizeResponse = _reflection.GeneratedProtocolMessageType('MsgRecollateralizeResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGRECOLLATERALIZERESPONSE,
  '__module__' : 'stablecoin.tx_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.stablecoin.v1.MsgRecollateralizeResponse)
  })
_sym_db.RegisterMessage(MsgRecollateralizeResponse)

MsgBuyback = _reflection.GeneratedProtocolMessageType('MsgBuyback', (_message.Message,), {
  'DESCRIPTOR' : _MSGBUYBACK,
  '__module__' : 'stablecoin.tx_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.stablecoin.v1.MsgBuyback)
  })
_sym_db.RegisterMessage(MsgBuyback)

MsgBuybackResponse = _reflection.GeneratedProtocolMessageType('MsgBuybackResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGBUYBACKRESPONSE,
  '__module__' : 'stablecoin.tx_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.stablecoin.v1.MsgBuybackResponse)
  })
_sym_db.RegisterMessage(MsgBuybackResponse)

_MSG = DESCRIPTOR.services_by_name['Msg']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z0github.com/NibiruChain/nibiru/x/stablecoin/types'
  _MSGMINTSTABLE.fields_by_name['stable']._options = None
  _MSGMINTSTABLE.fields_by_name['stable']._serialized_options = b'\310\336\037\000'
  _MSGMINTSTABLERESPONSE.fields_by_name['stable']._options = None
  _MSGMINTSTABLERESPONSE.fields_by_name['stable']._serialized_options = b'\310\336\037\000'
  _MSGMINTSTABLERESPONSE.fields_by_name['used_coins']._options = None
  _MSGMINTSTABLERESPONSE.fields_by_name['used_coins']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _MSGMINTSTABLERESPONSE.fields_by_name['fees_payed']._options = None
  _MSGMINTSTABLERESPONSE.fields_by_name['fees_payed']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _MSGBURNSTABLE.fields_by_name['stable']._options = None
  _MSGBURNSTABLE.fields_by_name['stable']._serialized_options = b'\310\336\037\000'
  _MSGBURNSTABLERESPONSE.fields_by_name['collateral']._options = None
  _MSGBURNSTABLERESPONSE.fields_by_name['collateral']._serialized_options = b'\310\336\037\000'
  _MSGBURNSTABLERESPONSE.fields_by_name['gov']._options = None
  _MSGBURNSTABLERESPONSE.fields_by_name['gov']._serialized_options = b'\310\336\037\000'
  _MSGBURNSTABLERESPONSE.fields_by_name['fees_payed']._options = None
  _MSGBURNSTABLERESPONSE.fields_by_name['fees_payed']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _MSGRECOLLATERALIZE.fields_by_name['coll']._options = None
  _MSGRECOLLATERALIZE.fields_by_name['coll']._serialized_options = b'\310\336\037\000'
  _MSGRECOLLATERALIZERESPONSE.fields_by_name['gov']._options = None
  _MSGRECOLLATERALIZERESPONSE.fields_by_name['gov']._serialized_options = b'\310\336\037\000'
  _MSGBUYBACK.fields_by_name['gov']._options = None
  _MSGBUYBACK.fields_by_name['gov']._serialized_options = b'\310\336\037\000'
  _MSGBUYBACKRESPONSE.fields_by_name['coll']._options = None
  _MSGBUYBACKRESPONSE.fields_by_name['coll']._serialized_options = b'\310\336\037\000'
  _MSG.methods_by_name['MintStable']._options = None
  _MSG.methods_by_name['MintStable']._serialized_options = b'\202\323\344\223\002\034\"\032/nibiru/stablecoin/mint-sc'
  _MSG.methods_by_name['BurnStable']._options = None
  _MSG.methods_by_name['BurnStable']._serialized_options = b'\202\323\344\223\002\034\"\032/nibiru/stablecoin/burn-sc'
  _MSG.methods_by_name['Recollateralize']._options = None
  _MSG.methods_by_name['Recollateralize']._serialized_options = b'\202\323\344\223\002\033\"\031/nibiru/stablecoin/recoll'
  _MSG.methods_by_name['Buyback']._options = None
  _MSG.methods_by_name['Buyback']._serialized_options = b'\202\323\344\223\002\034\"\032/nibiru/stablecoin/buyback'
  _MSGMINTSTABLE._serialized_start=129
  _MSGMINTSTABLE._serialized_end=210
  _MSGMINTSTABLERESPONSE._serialized_start=213
  _MSGMINTSTABLERESPONSE._serialized_end=479
  _MSGBURNSTABLE._serialized_start=481
  _MSGBURNSTABLE._serialized_end=562
  _MSGBURNSTABLERESPONSE._serialized_start=565
  _MSGBURNSTABLERESPONSE._serialized_end=784
  _MSGRECOLLATERALIZE._serialized_start=786
  _MSGRECOLLATERALIZE._serialized_end=870
  _MSGRECOLLATERALIZERESPONSE._serialized_start=872
  _MSGRECOLLATERALIZERESPONSE._serialized_end=946
  _MSGBUYBACK._serialized_start=948
  _MSGBUYBACK._serialized_end=1023
  _MSGBUYBACKRESPONSE._serialized_start=1025
  _MSGBUYBACKRESPONSE._serialized_end=1092
  _MSG._serialized_start=1095
  _MSG._serialized_end=1636
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/base/kv/v1beta1/kv.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x63osmos/base/kv/v1beta1/kv.proto\x12\x16\x63osmos.base.kv.v1beta1\x1a\x14gogoproto/gogo.proto\":\n\x05Pairs\x12\x31\n\x05pairs\x18\x01 \x03(\x0b\x32\x1c.cosmos.base.kv.v1beta1.PairB\x04\xc8\xde\x1f\x00\"\"\n\x04Pair\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12\r\n\x05value\x18\x02 \x01(\x0c\x42\'Z%github.com/cosmos/cosmos-sdk/types/kvb\x06proto3')



_PAIRS = DESCRIPTOR.message_types_by_name['Pairs']
_PAIR = DESCRIPTOR.message_types_by_name['Pair']
Pairs = _reflection.GeneratedProtocolMessageType('Pairs', (_message.Message,), {
  'DESCRIPTOR' : _PAIRS,
  '__module__' : 'cosmos.base.kv.v1beta1.kv_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.kv.v1beta1.Pairs)
  })
_sym_db.RegisterMessage(Pairs)

Pair = _reflection.GeneratedProtocolMessageType('Pair', (_message.Message,), {
  'DESCRIPTOR' : _PAIR,
  '__module__' : 'cosmos.base.kv.v1beta1.kv_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.kv.v1beta1.Pair)
  })
_sym_db.RegisterMessage(Pair)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z%github.com/cosmos/cosmos-sdk/types/kv'
  _PAIRS.fields_by_name['pairs']._options = None
  _PAIRS.fields_by_name['pairs']._serialized_options = b'\310\336\037\000'
  _PAIRS._serialized_start=81
  _PAIRS._serialized_end=139
  _PAIR._serialized_start=141
  _PAIR._serialized_end=175
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from dex.v1 import query_pb2 as dex_dot_v1_dot_query__pb2


class QueryStub(object):
    """Query defines the gRPC querier service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Params = channel.unary_unary(
                '/nibiru.dex.v1.Query/Params',
                request_serializer=dex_dot_v1_dot_query__pb2.QueryParamsRequest.SerializeToString,
                response_deserializer=dex_dot_v1_dot_query__pb2.QueryParamsResponse.FromString,
                )
        self.PoolNumber = channel.unary_unary(
                '/nibiru.dex.v1.Query/PoolNumber',
                request_serializer=dex_dot_v1_dot_query__pb2.QueryPoolNumberRequest.SerializeToString,
                response_deserializer=dex_dot_v1_dot_query__pb2.QueryPoolNumberResponse.FromString,
                )
        self.Pool = channel.unary_unary(
                '/nibiru.dex.v1.Query/Pool',
                request_serializer=dex_dot_v1_dot_query__pb2.QueryPoolRequest.SerializeToString,
                response_deserializer=dex_dot_v1_dot_query__pb2.QueryPoolResponse.FromString,
                )
        self.Pools = channel.unary_unary(
                '/nibiru.dex.v1.Query/Pools',
                request_serializer=dex_dot_v1_dot_query__pb2.QueryPoolsRequest.SerializeToString,
                response_deserializer=dex_dot_v1_dot_query__pb2.QueryPoolsResponse.FromString,
                )
        self.PoolParams = channel.unary_unary(
                '/nibiru.dex.v1.Query/PoolParams',
                request_serializer=dex_dot_v1_dot_query__pb2.QueryPoolParamsRequest.SerializeToString,
                response_deserializer=dex_dot_v1_dot_query__pb2.QueryPoolParamsResponse.FromString,
                )
        self.NumPools = channel.unary_unary(
                '/nibiru.dex.v1.Query/NumPools',
                request_serializer=dex_dot_v1_dot_query__pb2.QueryNumPoolsRequest.SerializeToString,
                response_deserializer=dex_dot_v1_dot_query__pb2.QueryNumPoolsResponse.FromString,
                )
        self.TotalLiquidity = channel.unary_unary(
                '/nibiru.dex.v1.Query/TotalLiquidity',
                request_serializer=dex_dot_v1_dot_query__pb2.QueryTotalLiquidityRequest.SerializeToString,
                response_deserializer=dex_dot_v1_dot_query__pb2.QueryTotalLiquidityResponse.FromString,
                )
        self.TotalPoolLiquidity = channel.unary_unary(
                '/nibiru.dex.v1.Query/TotalPoolLiquidity',
                request_serializer=dex_dot_v1_dot_query__pb2.QueryTotalPoolLiquidityRequest.SerializeToString,
                response_deserializer=dex_dot_v1_dot_query__pb2.QueryTotalPoolLiquidityResponse.FromString,
                )
        self.TotalShares = channel.unary_unary(
                '/nibiru.dex.v1.Query/TotalShares',
                request_serializer=dex_dot_v1_dot_query__pb2.QueryTotalSharesRequest.SerializeToString,
                response_deserializer=dex_dot_v1_dot_query__pb2.QueryTotalSharesResponse.FromString,
                )
        self.SpotPrice = channel.unary_unary(
                '/nibiru.dex.v1.Query/SpotPrice',
                request_serializer=dex_dot_v1_dot_query__pb2.QuerySpotPriceRequest.SerializeToString,
                response_deserializer=dex_dot_v1_dot_query__pb2.QuerySpotPriceResponse.FromString,
                )
        self.EstimateSwapExactAmountIn = channel.unary_unary(
                '/nibiru.dex.v1.Query/EstimateSwapExactAmountIn',
                request_serializer=dex_dot_v1_dot_query__pb2.QuerySwapExactAmountInRequest.SerializeToString,
                response_deserializer=dex_dot_v1_dot_query__pb2.QuerySwapExactAmountInResponse.FromString,
                )
        self.EstimateSwapExactAmountOut = channel.unary_unary(
                '/nibiru.dex.v1.Query/EstimateSwapExactAmountOut',
                request_serializer=dex_dot_v1_dot_query__pb2.QuerySwapExactAmountOutRequest.SerializeToString,
                response_deserializer=dex_dot_v1_dot_query__pb2.QuerySwapExactAmountOutResponse.FromString,
                )
        self.EstimateJoinExactAmountIn = channel.unary_unary(
                '/nibiru.dex.v1.Query/EstimateJoinExactAmountIn',
                request_serializer=dex_dot_v1_dot_query__pb2.QueryJoinExactAmountInRequest.SerializeToString,
                response_deserializer=dex_dot_v1_dot_query__pb2.QueryJoinExactAmountInResponse.FromString,
                )
        self.EstimateJoinExactAmountOut = channel.unary_unary(
                '/nibiru.dex.v1.Query/EstimateJoinExactAmountOut',
                request_serializer=dex_dot_v1_dot_query__pb2.QueryJoinExactAmountOutRequest.SerializeToString,
                response_deserializer=dex_dot_v1_dot_query__pb2.QueryJoinExactAmountOutResponse.FromString,
                )
        self.EstimateExitExactAmountIn = channel.unary_unary(
                '/nibiru.dex.v1.Query/EstimateExitExactAmountIn',
                request_serializer=dex_dot_v1_dot_query__pb2.QueryExitExactAmountInRequest.SerializeToString,
                response_deserializer=dex_dot_v1_dot_query__pb2.QueryExitExactAmountInResponse.FromString,
                )
        self.EstimateExitExactAmountOut = channel.unary_unary(
                '/nibiru.dex.v1.Query/EstimateExitExactAmountOut',
                request_serializer=dex_dot_v1_dot_query__pb2.QueryExitExactAmountOutRequest.SerializeToString,
                response_deserializer=dex_dot_v1_dot_query__pb2.QueryExitExactAmountOutResponse.FromString,
                )


class QueryServicer(object):
    """Query defines the gRPC querier service.
    """

    def Params(self, request, context):
        """Parameters of the dex module.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PoolNumber(self, request, context):
        """Next available pool id number.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Pool(self, request, context):
        """Fetch a pool by id.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Pools(self, request, context):
        """Returns all pools.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PoolParams(self, request, context):
        """Parameters of a single pool.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def NumPools(self, request, context):
        """Number of pools.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TotalLiquidity(self, request, context):
        """Total liquidity across all pools.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TotalPoolLiquidity(self, request, context):
        """Total liquidity in a single pool.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TotalShares(self, request, context):
        """Total shares in a single pool.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SpotPrice(self, request, context):
        """Instantaneous price of an asset in a pool.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EstimateSwapExactAmountIn(self, request, context):
        """Estimates the amount of assets returned given an exact amount of tokens to
        swap.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EstimateSwapExactAmountOut(self, request, context):
        """Estimates the amount of tokens required to return the exact amount of
        assets requested.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EstimateJoinExactAmountIn(self, request, context):
        """Estimates the amount of pool shares returned given an amount of tokens to
        join.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EstimateJoinExactAmountOut(self, request, context):
        """Estimates the amount of tokens required to obtain an exact amount of pool
        shares.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EstimateExitExactAmountIn(self, request, context):
        """Estimates the amount of tokens returned to the user given an exact amount
        of pool shares.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EstimateExitExactAmountOut(self, request, context):
        """Estimates the amount of pool shares required to extract an exact amount of
        tokens from the pool.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Params': grpc.unary_unary_rpc_method_handler(
                    servicer.Params,
                    request_deserializer=dex_dot_v1_dot_query__pb2.QueryParamsRequest.FromString,
                    response_serializer=dex_dot_v1_dot_query__pb2.QueryParamsResponse.SerializeToString,
            ),
            'PoolNumber': grpc.unary_unary_rpc_method_handler(
                    servicer.PoolNumber,
                    request_deserializer=dex_dot_v1_dot_query__pb2.QueryPoolNumberRequest.FromString,
                    response_serializer=dex_dot_v1_dot_query__pb2.QueryPoolNumberResponse.SerializeToString,
            ),
            'Pool': grpc.unary_unary_rpc_method_handler(
                    servicer.Pool,
                    request_deserializer=dex_dot_v1_dot_query__pb2.QueryPoolRequest.FromString,
                    response_serializer=dex_dot_v1_dot_query__pb2.QueryPoolResponse.SerializeToString,
            ),
            'Pools': grpc.unary_unary_rpc_method_handler(
                    servicer.Pools,
                    request_deserializer=dex_dot_v1_dot_query__pb2.QueryPoolsRequest.FromString,
                    response_serializer=dex_dot_v1_dot_query__pb2.QueryPoolsResponse.SerializeToString,
            ),
            'PoolParams': grpc.unary_unary_rpc_method_handler(
                    servicer.PoolParams,
                    request_deserializer=dex_dot_v1_dot_query__pb2.QueryPoolParamsRequest.FromString,
                    response_serializer=dex_dot_v1_dot_query__pb2.QueryPoolParamsResponse.SerializeToString,
            ),
            'NumPools': grpc.unary_unary_rpc_method_handler(
                    servicer.NumPools,
                    request_deserializer=dex_dot_v1_dot_query__pb2.QueryNumPoolsRequest.FromString,
                    response_serializer=dex_dot_v1_dot_query__pb2.QueryNumPoolsResponse.SerializeToString,
            ),
            'TotalLiquidity': grpc.unary_unary_rpc_method_handler(
                    servicer.TotalLiquidity,
                    request_deserializer=dex_dot_v1_dot_query__pb2.QueryTotalLiquidityRequest.FromString,
                    response_serializer=dex_dot_v1_dot_query__pb2.QueryTotalLiquidityResponse.SerializeToString,
            ),
            'TotalPoolLiquidity': grpc.unary_unary_rpc_method_handler(
                    servicer.TotalPoolLiquidity,
                    request_deserializer=dex_dot_v1_dot_query__pb2.QueryTotalPoolLiquidityRequest.FromString,
                    response_serializer=dex_dot_v1_dot_query__pb2.QueryTotalPoolLiquidityResponse.SerializeToString,
            ),
            'TotalShares': grpc.unary_unary_rpc_method_handler(
                    servicer.TotalShares,
                    request_deserializer=dex_dot_v1_dot_query__pb2.QueryTotalSharesRequest.FromString,
                    response_serializer=dex_dot_v1_dot_query__pb2.QueryTotalSharesResponse.SerializeToString,
            ),
            'SpotPrice': grpc.unary_unary_rpc_method_handler(
                    servicer.SpotPrice,
                    request_deserializer=dex_dot_v1_dot_query__pb2.QuerySpotPriceRequest.FromString,
                    response_serializer=dex_dot_v1_dot_query__pb2.QuerySpotPriceResponse.SerializeToString,
            ),
            'EstimateSwapExactAmountIn': grpc.unary_unary_rpc_method_handler(
                    servicer.EstimateSwapExactAmountIn,
                    request_deserializer=dex_dot_v1_dot_query__pb2.QuerySwapExactAmountInRequest.FromString,
                    response_serializer=dex_dot_v1_dot_query__pb2.QuerySwapExactAmountInResponse.SerializeToString,
            ),
            'EstimateSwapExactAmountOut': grpc.unary_unary_rpc_method_handler(
                    servicer.EstimateSwapExactAmountOut,
                    request_deserializer=dex_dot_v1_dot_query__pb2.QuerySwapExactAmountOutRequest.FromString,
                    response_serializer=dex_dot_v1_dot_query__pb2.QuerySwapExactAmountOutResponse.SerializeToString,
            ),
            'EstimateJoinExactAmountIn': grpc.unary_unary_rpc_method_handler(
                    servicer.EstimateJoinExactAmountIn,
                    request_deserializer=dex_dot_v1_dot_query__pb2.QueryJoinExactAmountInRequest.FromString,
                    response_serializer=dex_dot_v1_dot_query__pb2.QueryJoinExactAmountInResponse.SerializeToString,
            ),
            'EstimateJoinExactAmountOut': grpc.unary_unary_rpc_method_handler(
                    servicer.EstimateJoinExactAmountOut,
                    request_deserializer=dex_dot_v1_dot_query__pb2.QueryJoinExactAmountOutRequest.FromString,
                    response_serializer=dex_dot_v1_dot_query__pb2.QueryJoinExactAmountOutResponse.SerializeToString,
            ),
            'EstimateExitExactAmountIn': grpc.unary_unary_rpc_method_handler(
                    servicer.EstimateExitExactAmountIn,
                    request_deserializer=dex_dot_v1_dot_query__pb2.QueryExitExactAmountInRequest.FromString,
                    response_serializer=dex_dot_v1_dot_query__pb2.QueryExitExactAmountInResponse.SerializeToString,
            ),
            'EstimateExitExactAmountOut': grpc.unary_unary_rpc_method_handler(
                    servicer.EstimateExitExactAmountOut,
                    request_deserializer=dex_dot_v1_dot_query__pb2.QueryExitExactAmountOutRequest.FromString,
                    response_serializer=dex_dot_v1_dot_query__pb2.QueryExitExactAmountOutResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'nibiru.dex.v1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query defines the gRPC querier service.
    """

    @staticmethod
    def Params(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.dex.v1.Query/Params',
            dex_dot_v1_dot_query__pb2.QueryParamsRequest.SerializeToString,
            dex_dot_v1_dot_query__pb2.QueryParamsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PoolNumber(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.dex.v1.Query/PoolNumber',
            dex_dot_v1_dot_query__pb2.QueryPoolNumberRequest.SerializeToString,
            dex_dot_v1_dot_query__pb2.QueryPoolNumberResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Pool(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.dex.v1.Query/Pool',
            dex_dot_v1_dot_query__pb2.QueryPoolRequest.SerializeToString,
            dex_dot_v1_dot_query__pb2.QueryPoolResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Pools(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.dex.v1.Query/Pools',
            dex_dot_v1_dot_query__pb2.QueryPoolsRequest.SerializeToString,
            dex_dot_v1_dot_query__pb2.QueryPoolsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PoolParams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.dex.v1.Query/PoolParams',
            dex_dot_v1_dot_query__pb2.QueryPoolParamsRequest.SerializeToString,
            dex_dot_v1_dot_query__pb2.QueryPoolParamsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def NumPools(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.dex.v1.Query/NumPools',
            dex_dot_v1_dot_query__pb2.QueryNumPoolsRequest.SerializeToString,
            dex_dot_v1_dot_query__pb2.QueryNumPoolsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TotalLiquidity(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.dex.v1.Query/TotalLiquidity',
            dex_dot_v1_dot_query__pb2.QueryTotalLiquidityRequest.SerializeToString,
            dex_dot_v1_dot_query__pb2.QueryTotalLiquidityResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TotalPoolLiquidity(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.dex.v1.Query/TotalPoolLiquidity',
            dex_dot_v1_dot_query__pb2.QueryTotalPoolLiquidityRequest.SerializeToString,
            dex_dot_v1_dot_query__pb2.QueryTotalPoolLiquidityResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TotalShares(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.dex.v1.Query/TotalShares',
            dex_dot_v1_dot_query__pb2.QueryTotalSharesRequest.SerializeToString,
            dex_dot_v1_dot_query__pb2.QueryTotalSharesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SpotPrice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.dex.v1.Query/SpotPrice',
            dex_dot_v1_dot_query__pb2.QuerySpotPriceRequest.SerializeToString,
            dex_dot_v1_dot_query__pb2.QuerySpotPriceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EstimateSwapExactAmountIn(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.dex.v1.Query/EstimateSwapExactAmountIn',
            dex_dot_v1_dot_query__pb2.QuerySwapExactAmountInRequest.SerializeToString,
            dex_dot_v1_dot_query__pb2.QuerySwapExactAmountInResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EstimateSwapExactAmountOut(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.dex.v1.Query/EstimateSwapExactAmountOut',
            dex_dot_v1_dot_query__pb2.QuerySwapExactAmountOutRequest.SerializeToString,
            dex_dot_v1_dot_query__pb2.QuerySwapExactAmountOutResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EstimateJoinExactAmountIn(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.dex.v1.Query/EstimateJoinExactAmountIn',
            dex_dot_v1_dot_query__pb2.QueryJoinExactAmountInRequest.SerializeToString,
            dex_dot_v1_dot_query__pb2.QueryJoinExactAmountInResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EstimateJoinExactAmountOut(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.dex.v1.Query/EstimateJoinExactAmountOut',
            dex_dot_v1_dot_query__pb2.QueryJoinExactAmountOutRequest.SerializeToString,
            dex_dot_v1_dot_query__pb2.QueryJoinExactAmountOutResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EstimateExitExactAmountIn(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.dex.v1.Query/EstimateExitExactAmountIn',
            dex_dot_v1_dot_query__pb2.QueryExitExactAmountInRequest.SerializeToString,
            dex_dot_v1_dot_query__pb2.QueryExitExactAmountInResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EstimateExitExactAmountOut(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.dex.v1.Query/EstimateExitExactAmountOut',
            dex_dot_v1_dot_query__pb2.QueryExitExactAmountOutRequest.SerializeToString,
            dex_dot_v1_dot_query__pb2.QueryExitExactAmountOutResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/authz/v1beta1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from cosmos.authz.v1beta1 import authz_pb2 as cosmos_dot_authz_dot_v1beta1_dot_authz__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n cosmos/authz/v1beta1/query.proto\x12\x14\x63osmos.authz.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a cosmos/authz/v1beta1/authz.proto\"\x88\x01\n\x12QueryGrantsRequest\x12\x0f\n\x07granter\x18\x01 \x01(\t\x12\x0f\n\x07grantee\x18\x02 \x01(\t\x12\x14\n\x0cmsg_type_url\x18\x03 \x01(\t\x12:\n\npagination\x18\x04 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x7f\n\x13QueryGrantsResponse\x12+\n\x06grants\x18\x01 \x03(\x0b\x32\x1b.cosmos.authz.v1beta1.Grant\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"h\n\x19QueryGranterGrantsRequest\x12\x0f\n\x07granter\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x93\x01\n\x1aQueryGranterGrantsResponse\x12\x38\n\x06grants\x18\x01 \x03(\x0b\x32(.cosmos.authz.v1beta1.GrantAuthorization\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"h\n\x19QueryGranteeGrantsRequest\x12\x0f\n\x07grantee\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x93\x01\n\x1aQueryGranteeGrantsResponse\x12\x38\n\x06grants\x18\x01 \x03(\x0b\x32(.cosmos.authz.v1beta1.GrantAuthorization\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse2\xe7\x03\n\x05Query\x12\x83\x01\n\x06Grants\x12(.cosmos.authz.v1beta1.QueryGrantsRequest\x1a).cosmos.authz.v1beta1.QueryGrantsResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/cosmos/authz/v1beta1/grants\x12\xaa\x01\n\rGranterGrants\x12/.cosmos.authz.v1beta1.QueryGranterGrantsRequest\x1a\x30.cosmos.authz.v1beta1.QueryGranterGrantsResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./cosmos/authz/v1beta1/grants/granter/{granter}\x12\xaa\x01\n\rGranteeGrants\x12/.cosmos.authz.v1beta1.QueryGranteeGrantsRequest\x1a\x30.cosmos.authz.v1beta1.QueryGranteeGrantsResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./cosmos/authz/v1beta1/grants/grantee/{grantee}B&Z$github.com/cosmos/cosmos-sdk/x/authzb\x06proto3')



_QUERYGRANTSREQUEST = DESCRIPTOR.message_types_by_name['QueryGrantsRequest']
_QUERYGRANTSRESPONSE = DESCRIPTOR.message_types_by_name['QueryGrantsResponse']
_QUERYGRANTERGRANTSREQUEST = DESCRIPTOR.message_types_by_name['QueryGranterGrantsRequest']
_QUERYGRANTERGRANTSRESPONSE = DESCRIPTOR.message_types_by_name['QueryGranterGrantsResponse']
_QUERYGRANTEEGRANTSREQUEST = DESCRIPTOR.message_types_by_name['QueryGranteeGrantsRequest']
_QUERYGRANTEEGRANTSRESPONSE = DESCRIPTOR.message_types_by_name['QueryGranteeGrantsResponse']
QueryGrantsRequest = _reflection.GeneratedProtocolMessageType('QueryGrantsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYGRANTSREQUEST,
  '__module__' : 'cosmos.authz.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.authz.v1beta1.QueryGrantsRequest)
  })
_sym_db.RegisterMessage(QueryGrantsRequest)

QueryGrantsResponse = _reflection.GeneratedProtocolMessageType('QueryGrantsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYGRANTSRESPONSE,
  '__module__' : 'cosmos.authz.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.authz.v1beta1.QueryGrantsResponse)
  })
_sym_db.RegisterMessage(QueryGrantsResponse)

QueryGranterGrantsRequest = _reflection.GeneratedProtocolMessageType('QueryGranterGrantsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYGRANTERGRANTSREQUEST,
  '__module__' : 'cosmos.authz.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.authz.v1beta1.QueryGranterGrantsRequest)
  })
_sym_db.RegisterMessage(QueryGranterGrantsRequest)

QueryGranterGrantsResponse = _reflection.GeneratedProtocolMessageType('QueryGranterGrantsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYGRANTERGRANTSRESPONSE,
  '__module__' : 'cosmos.authz.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.authz.v1beta1.QueryGranterGrantsResponse)
  })
_sym_db.RegisterMessage(QueryGranterGrantsResponse)

QueryGranteeGrantsRequest = _reflection.GeneratedProtocolMessageType('QueryGranteeGrantsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYGRANTEEGRANTSREQUEST,
  '__module__' : 'cosmos.authz.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.authz.v1beta1.QueryGranteeGrantsRequest)
  })
_sym_db.RegisterMessage(QueryGranteeGrantsRequest)

QueryGranteeGrantsResponse = _reflection.GeneratedProtocolMessageType('QueryGranteeGrantsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYGRANTEEGRANTSRESPONSE,
  '__module__' : 'cosmos.authz.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.authz.v1beta1.QueryGranteeGrantsResponse)
  })
_sym_db.RegisterMessage(QueryGranteeGrantsResponse)

_QUERY = DESCRIPTOR.services_by_name['Query']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z$github.com/cosmos/cosmos-sdk/x/authz'
  _QUERY.methods_by_name['Grants']._options = None
  _QUERY.methods_by_name['Grants']._serialized_options = b'\202\323\344\223\002\036\022\034/cosmos/authz/v1beta1/grants'
  _QUERY.methods_by_name['GranterGrants']._options = None
  _QUERY.methods_by_name['GranterGrants']._serialized_options = b'\202\323\344\223\0020\022./cosmos/authz/v1beta1/grants/granter/{granter}'
  _QUERY.methods_by_name['GranteeGrants']._options = None
  _QUERY.methods_by_name['GranteeGrants']._serialized_options = b'\202\323\344\223\0020\022./cosmos/authz/v1beta1/grants/grantee/{grantee}'
  _QUERYGRANTSREQUEST._serialized_start=167
  _QUERYGRANTSREQUEST._serialized_end=303
  _QUERYGRANTSRESPONSE._serialized_start=305
  _QUERYGRANTSRESPONSE._serialized_end=432
  _QUERYGRANTERGRANTSREQUEST._serialized_start=434
  _QUERYGRANTERGRANTSREQUEST._serialized_end=538
  _QUERYGRANTERGRANTSRESPONSE._serialized_start=541
  _QUERYGRANTERGRANTSRESPONSE._serialized_end=688
  _QUERYGRANTEEGRANTSREQUEST._serialized_start=690
  _QUERYGRANTEEGRANTSREQUEST._serialized_end=794
  _QUERYGRANTEEGRANTSRESPONSE._serialized_start=797
  _QUERYGRANTEEGRANTSRESPONSE._serialized_end=944
  _QUERY._serialized_start=947
  _QUERY._serialized_end=1434
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from dex.v1 import tx_pb2 as dex_dot_v1_dot_tx__pb2


class MsgStub(object):
    """Msg defines the Msg service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreatePool = channel.unary_unary(
                '/nibiru.dex.v1.Msg/CreatePool',
                request_serializer=dex_dot_v1_dot_tx__pb2.MsgCreatePool.SerializeToString,
                response_deserializer=dex_dot_v1_dot_tx__pb2.MsgCreatePoolResponse.FromString,
                )
        self.JoinPool = channel.unary_unary(
                '/nibiru.dex.v1.Msg/JoinPool',
                request_serializer=dex_dot_v1_dot_tx__pb2.MsgJoinPool.SerializeToString,
                response_deserializer=dex_dot_v1_dot_tx__pb2.MsgJoinPoolResponse.FromString,
                )
        self.ExitPool = channel.unary_unary(
                '/nibiru.dex.v1.Msg/ExitPool',
                request_serializer=dex_dot_v1_dot_tx__pb2.MsgExitPool.SerializeToString,
                response_deserializer=dex_dot_v1_dot_tx__pb2.MsgExitPoolResponse.FromString,
                )
        self.SwapAssets = channel.unary_unary(
                '/nibiru.dex.v1.Msg/SwapAssets',
                request_serializer=dex_dot_v1_dot_tx__pb2.MsgSwapAssets.SerializeToString,
                response_deserializer=dex_dot_v1_dot_tx__pb2.MsgSwapAssetsResponse.FromString,
                )


class MsgServicer(object):
    """Msg defines the Msg service.
    """

    def CreatePool(self, request, context):
        """Used to create a pool.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def JoinPool(self, request, context):
        """Join a pool as a liquidity provider.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExitPool(self, request, context):
        """Exit a pool position by returning LP shares
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SwapAssets(self, request, context):
        """Swap assets in a pool
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreatePool': grpc.unary_unary_rpc_method_handler(
                    servicer.CreatePool,
                    request_deserializer=dex_dot_v1_dot_tx__pb2.MsgCreatePool.FromString,
                    response_serializer=dex_dot_v1_dot_tx__pb2.MsgCreatePoolResponse.SerializeToString,
            ),
            'JoinPool': grpc.unary_unary_rpc_method_handler(
                    servicer.JoinPool,
                    request_deserializer=dex_dot_v1_dot_tx__pb2.MsgJoinPool.FromString,
                    response_serializer=dex_dot_v1_dot_tx__pb2.MsgJoinPoolResponse.SerializeToString,
            ),
            'ExitPool': grpc.unary_unary_rpc_method_handler(
                    servicer.ExitPool,
                    request_deserializer=dex_dot_v1_dot_tx__pb2.MsgExitPool.FromString,
                    response_serializer=dex_dot_v1_dot_tx__pb2.MsgExitPoolResponse.SerializeToString,
            ),
            'SwapAssets': grpc.unary_unary_rpc_method_handler(
                    servicer.SwapAssets,
                    request_deserializer=dex_dot_v1_dot_tx__pb2.MsgSwapAssets.FromString,
                    response_serializer=dex_dot_v1_dot_tx__pb2.MsgSwapAssetsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'nibiru.dex.v1.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Msg defines the Msg service.
    """

    @staticmethod
    def CreatePool(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.dex.v1.Msg/CreatePool',
            dex_dot_v1_dot_tx__pb2.MsgCreatePool.SerializeToString,
            dex_dot_v1_dot_tx__pb2.MsgCreatePoolResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def JoinPool(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.dex.v1.Msg/JoinPool',
            dex_dot_v1_dot_tx__pb2.MsgJoinPool.SerializeToString,
            dex_dot_v1_dot_tx__pb2.MsgJoinPoolResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ExitPool(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.dex.v1.Msg/ExitPool',
            dex_dot_v1_dot_tx__pb2.MsgExitPool.SerializeToString,
            dex_dot_v1_dot_tx__pb2.MsgExitPoolResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SwapAssets(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.dex.v1.Msg/SwapAssets',
            dex_dot_v1_dot_tx__pb2.MsgSwapAssets.SerializeToString,
            dex_dot_v1_dot_tx__pb2.MsgSwapAssetsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/crypto/ed25519/keys.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n cosmos/crypto/ed25519/keys.proto\x12\x15\x63osmos.crypto.ed25519\x1a\x14gogoproto/gogo.proto\"9\n\x06PubKey\x12)\n\x03key\x18\x01 \x01(\x0c\x42\x1c\xfa\xde\x1f\x18\x63rypto/ed25519.PublicKey:\x04\x98\xa0\x1f\x00\"5\n\x07PrivKey\x12*\n\x03key\x18\x01 \x01(\x0c\x42\x1d\xfa\xde\x1f\x19\x63rypto/ed25519.PrivateKeyB2Z0github.com/cosmos/cosmos-sdk/crypto/keys/ed25519b\x06proto3')



_PUBKEY = DESCRIPTOR.message_types_by_name['PubKey']
_PRIVKEY = DESCRIPTOR.message_types_by_name['PrivKey']
PubKey = _reflection.GeneratedProtocolMessageType('PubKey', (_message.Message,), {
  'DESCRIPTOR' : _PUBKEY,
  '__module__' : 'cosmos.crypto.ed25519.keys_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.crypto.ed25519.PubKey)
  })
_sym_db.RegisterMessage(PubKey)

PrivKey = _reflection.GeneratedProtocolMessageType('PrivKey', (_message.Message,), {
  'DESCRIPTOR' : _PRIVKEY,
  '__module__' : 'cosmos.crypto.ed25519.keys_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.crypto.ed25519.PrivKey)
  })
_sym_db.RegisterMessage(PrivKey)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z0github.com/cosmos/cosmos-sdk/crypto/keys/ed25519'
  _PUBKEY.fields_by_name['key']._options = None
  _PUBKEY.fields_by_name['key']._serialized_options = b'\372\336\037\030crypto/ed25519.PublicKey'
  _PUBKEY._options = None
  _PUBKEY._serialized_options = b'\230\240\037\000'
  _PRIVKEY.fields_by_name['key']._options = None
  _PRIVKEY.fields_by_name['key']._serialized_options = b'\372\336\037\031crypto/ed25519.PrivateKey'
  _PUBKEY._serialized_start=81
  _PUBKEY._serialized_end=138
  _PRIVKEY._serialized_start=140
  _PRIVKEY._serialized_end=193
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: lockup/v1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from lockup.v1 import lock_pb2 as lockup_dot_v1_dot_lock__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17lockup/v1/genesis.proto\x12\x10nibiru.lockup.v1\x1a\x14gogoproto/gogo.proto\x1a\x14lockup/v1/lock.proto\"5\n\x0cGenesisState\x12%\n\x05locks\x18\x01 \x03(\x0b\x32\x16.nibiru.lockup.v1.LockB.Z,github.com/NibiruChain/nibiru/x/lockup/typesb\x06proto3')



_GENESISSTATE = DESCRIPTOR.message_types_by_name['GenesisState']
GenesisState = _reflection.GeneratedProtocolMessageType('GenesisState', (_message.Message,), {
  'DESCRIPTOR' : _GENESISSTATE,
  '__module__' : 'lockup.v1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.lockup.v1.GenesisState)
  })
_sym_db.RegisterMessage(GenesisState)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z,github.com/NibiruChain/nibiru/x/lockup/types'
  _GENESISSTATE._serialized_start=89
  _GENESISSTATE._serialized_end=142
# @@protoc_insertion_point(module_scope)
